@@ -30,7 +30,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -1593,6 +1593,11 @@ sub _send_request {
     my ( $self, $object ) = @_;
     my $json   = JSON::encode_json($object);
     my $length = length $json;
+if (!defined $self->_socket()) {
+	use Data::Dumper;
+	print STDERR Dumper($self);
+	Carp::cluck("WTF");
+}
     my $result = syswrite $self->_socket(), "$length:$json";
     if ( !defined $result ) {
         Carp::croak("Failed to send request to firefox:$EXTENDED_OS_ERROR");
@@ -1674,7 +1679,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.21
+Version 0.22
 
 =head1 SYNOPSIS
 
